# space-exploration-common-lib

## About the application
sample text

## Available Scripts

#### coverage html

#### python -m build

#### 'pip install -r requirements.txt'

#### python -m pytest --cov-report=xml:reports/coverage.xml --cov-report term-missing --cov=src -W ignore